# -*- coding: utf-8 -*-

# Copyright (c) 2003 Detlev Offenbach <detlev@die-offenbachs.de>
#

"""
Module implementing the Subversion command dialog.
"""

from qt import *

from CommandForm import CommandForm

class SvnCommandDialog(CommandForm):
    """
    Class implementing the Subversion command dialog.
    
    It implements a dialog that is used to enter an
    arbitrary subversion command. It asks the user to enter
    the commandline parameters and the working directory.
    """
    def __init__(self, argvList, wdList, ppath, parent=None):
        """
        Constructor
        
        Arguments
        
            argvList -- history list of commandline arguments (QStringList)
            
            wdList -- history list of working directories (QStringList)
            
            ppath -- pathname of the project directory (string)
            
            parent -- parent widget of this dialog (QWidget)
        """
        CommandForm.__init__(self, parent, None, 1)
        
        self.commandCombo.clear()
        self.commandCombo.insertStringList(argvList)
        if argvList.count() > 0:
            self.commandCombo.setCurrentItem(0)
        self.workdirCombo.clear()
        self.workdirCombo.insertStringList(wdList)
        if wdList.count() > 0:
            self.workdirCombo.setCurrentItem(0)
        self.projectDirLabel.setText(ppath)
        
    def handleDir(self):
        """
        Private method used to open a directory selection dialog.
        """
        cwd = self.workdirCombo.currentText()
        if cwd.isEmpty():
            cwd = self.projectDirLabel.text()
        d = QFileDialog.getExistingDirectory(cwd,
            self, None, self.trUtf8('Working directory'))
            
        if not d.isEmpty():
            self.workdirCombo.setCurrentText(QDir.convertSeparators(d))
        
    def enableOkButton(self, text):
        """
        Private method used to enable/disable the OK-button.
        
        Arguments
        
            text -- ignored
        """
        self.okButton.setDisabled(self.commandCombo.currentText().isEmpty())
    
    def getData(self):
        """
        Public method to retrieve the data entered into this dialog.
        
        Returns
        
            a tuple of argv, workdir
        """
        return (self.commandCombo.currentText(),
                self.workdirCombo.currentText())
